@@ -179,6 +179,74 @@
         <translation>Połączenia: oczekiwano skryptu</translation>
     </message>
 </context>
+<context>
+    <name>QQmlDebugServerImpl</name>
+    <message>
+        <source>QML Debugger: Invalid argument &quot;%1&quot; detected. Ignoring the same.</source>
+        <translation>Debugger QML: wykryto niepoprawny argument &quot;%1&quot;, zostanie on zignorowany.</translation>
+    </message>
+    <message>
+        <source>QML Debugger: Ignoring &quot;-qmljsdebugger=%1&quot;.</source>
+        <translation>Debugger QML: &quot;-qmljsdebugger=%1&quot; zostanie zignorowane.</translation>
+    </message>
+    <message>
+        <source>The format is &quot;-qmljsdebugger=[file:&lt;file&gt;|port:&lt;port_from&gt;][,&lt;port_to&gt;][,host:&lt;ip address&gt;][,block][,services:&lt;service&gt;][,&lt;service&gt;]*&quot;</source>
+        <translation>Formatem jest &quot;-qmljsdebugger=[file:&lt;plik&gt;|port:&lt;z portu&gt;][,&lt;do portu&gt;][,host:&lt;adres ip&gt;][,block][,services:&lt;serwis&gt;][,&lt;service&gt;]*&quot;</translation>
+    </message>
+    <message>
+        <source>&quot;file:&quot; can be used to specify the name of a file the debugger will try to connect to using a QLocalSocket. If &quot;file:&quot; is given any &quot;host:&quot; and&quot;port:&quot; arguments will be ignored.</source>
+        <translation>&quot;file:&quot; służy do podania nazwy pliku, do którego debugger będzie próbował się podłączyć używając QLocalSocket. Jeśli wraz z &quot;file:&quot; podano również &quot;host:&quot; lub &quot;port:&quot;, argumenty te zostaną zignorowane.</translation>
+    </message>
+    <message>
+        <source>&quot;host:&quot; and &quot;port:&quot; can be used to specify an address and a single port or a range of ports the debugger will try to bind to with a QTcpServer.</source>
+        <translation>&quot;host:&quot; i &quot;port:&quot; służą do podania adresu i pojedynczego portu lub zakresu portów, przez które debugger będzie próbował nawiązać połączenie przy użyciu QTcpServer.</translation>
+    </message>
+    <message>
+        <source>&quot;block&quot; makes the debugger and some services wait for clients to be connected and ready before the first QML engine starts.</source>
+        <translation>&quot;block&quot; nakazuje debuggerowi i niektórym serwisom oczekiwanie na połączenie i gotowość klientów przed pierwszym uruchomieniem silnika QML.</translation>
+    </message>
+    <message>
+        <source>&quot;services:&quot; can be used to specify which debug services the debugger should load. Some debug services interact badly with others. The V4 debugger should not be loaded when using the QML profiler as it will force any V4 engines to use the JavaScript interpreter rather than the JIT. The following debug services are available by default:</source>
+        <translation>&quot;services:&quot; służą do podania nazw serwisów, które debugger powinien załadować. Niektóre serwisy nie współdziałają dobrze ze sobą. Debugger V4 nie powinien być załadowany kiedy używany jest profiler QML, ponieważ zmusza on wszystkie silniki V4 do używania interpretera JavaScript zamiast JIT. Następujące serwisy są domyślnie dostępne:</translation>
+    </message>
+    <message>
+        <source>The QML debugger</source>
+        <translation>Debugger QML</translation>
+    </message>
+    <message>
+        <source>The V4 debugger</source>
+        <translation>Debugger V4</translation>
+    </message>
+    <message>
+        <source>The QML inspector</source>
+        <translation>Inspektor QML</translation>
+    </message>
+    <message>
+        <source>The QML profiler</source>
+        <translation>Profiler QML</translation>
+    </message>
+    <message>
+        <source>Allows the client to delay the starting and stopping of
+		  QML engines until other services are ready. QtCreator
+		  uses this service with the QML profiler in order to
+		  profile multiple QML engines at the same time.</source>
+        <translation>Pozwala klientom na opóźnione uruchomienie bądź zatrzymanie
+		  silników QML do momentu gdy inne serwisy są gotowe. QtCreator
+		  używa tego serwisu do profilowania wielu silników QML jednocześnie.</translation>
+    </message>
+    <message>
+        <source>Sends qDebug() and similar messages over the QML debug
+		  connection. QtCreator uses this for showing debug
+		  messages in the debugger console.</source>
+        <translation>Wysyła komunikaty qDebug() i podobne przez połączenie debugowe QML.
+		  QtCreator używa go do pokazywania komunikatów
+		  debugowych w konsoli debuggera.</translation>
+    </message>
+    <message>
+        <source>Other services offered by qmltooling plugins that implement QQmlDebugServiceFactory and which can be found in the standard plugin paths will also be available and can be specified. If no &quot;services&quot; argument is given, all services found this way, including the default ones, are loaded.</source>
+        <translation>Inne serwisy, dostępne we wtyczkach qmltooling, które implementują QQmlDebugServiceFactory i które mogą być odnalezione w standardowych ścieżkach do wtyczek, również mogą zostać podane. Jeśli nie podano argumentu &quot;services&quot;, wszystkie serwisy odnalezione w ten sposób, włącznie z domyślnymi, zostaną załadowane.</translation>
+    </message>
+</context>
 <context>
     <name>QQmlDelegateModel</name>
     <message>
@@ -334,6 +402,10 @@
 </context>
 <context>
     <name>QQmlEnumTypeResolver</name>
+    <message>
+        <source>Invalid property assignment: Enum value &quot;%1&quot; cannot start with a lowercase letter</source>
+        <translation>Niepoprawne przypisanie wartości: wartość typu wyliczeniowego &quot;%1&quot; nie może rozpoczynać się od małej litery</translation>
+    </message>
     <message>
         <source>Invalid property assignment: &quot;%1&quot; is a read-only property</source>
         <translation>Niepoprawne przypisanie wartości: &quot;%1&quot; jest właściwością tylko do odczytu</translation>
@@ -343,7 +415,7 @@
     <name>QQmlImportDatabase</name>
     <message>
         <source>&quot;%1&quot; is ambiguous. Found in %2 and in %3</source>
-        <translation>&quot;%1&quot; jest niejednoznanczy. Znaleziono w %2 i w %3</translation>
+        <translation>&quot;%1&quot; jest niejednoznaczny. Znaleziono w %2 i w %3</translation>
     </message>
     <message>
         <source>- %1 is not a namespace</source>
@@ -397,6 +469,10 @@
         <source>module &quot;%1&quot; plugin &quot;%2&quot; not found</source>
         <translation>wtyczka &quot;%2&quot; modułu &quot;%1&quot; nie została odnaleziona</translation>
     </message>
+    <message>
+        <source>library loading is disabled</source>
+        <translation>ładowanie bibliotek wyłączone</translation>
+    </message>
     <message>
         <source>&quot;%1&quot; version %2.%3 is defined more than once in module &quot;%4&quot;</source>
         <translation>&quot;%1&quot; wersji %2.%3 jest zdefiniowany wielokrotnie w module &quot;%4&quot;</translation>
@@ -627,7 +703,7 @@
     </message>
     <message>
         <source>Illegal hexadecimal escape sequence</source>
-        <translation>Niepoprawna szestastkowa sekwencja escape</translation>
+        <translation>Niepoprawna szesnastkowa sekwencja escape</translation>
     </message>
     <message>
         <source>Octal escape sequences are not allowed</source>
@@ -1173,6 +1249,13 @@
         <translation>setSource: wartość nie jest obiektem</translation>
     </message>
 </context>
+<context>
+    <name>QQuickMouseEvent</name>
+    <message>
+        <source>MouseEvent is only available within handlers in MouseArea</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QQuickOpenGLInfo</name>
     <message>
@@ -1260,10 +1343,6 @@
         <source>Cannot open: %1</source>
         <translation>Nie można otworzyć: %1</translation>
     </message>
-    <message>
-        <source>Invalid image data: %1</source>
-        <translation>Niepoprawne dane obrazu: %1</translation>
-    </message>
 </context>
 <context>
     <name>QQuickPropertyAnimation</name>
@@ -1327,7 +1406,10 @@ This is most likely caused by not having the necessary graphics drivers installe
 
 Install a driver providing OpenGL 2.0 or higher, or, if this is not possible, make sure the ANGLE Open GL ES 2.0 emulation libraries (%3, %4 and d3dcompiler_*.dll) are available in the application executable&apos;s directory or in a location listed in PATH.</source>
         <extracomment>%1 Context type (Open GL, EGL), %2 format, ANGLE %3, %4 library names</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>Błąd tworzenia kontekstu %1 w formacie %2.
+Najprawdopodobniej jest to spowodowane brakiem wymaganych sterowników graficznych.
+
+Zainstaluj sterownik obsługujący OpenGL w wersji 2.0 lub wyższej, lub jeśli to niemożliwe upewnij się, że biblioteki emulatora ANGLE Open GL ES 2.0 (%3, %4 i d3dcompiler_*.dll) są dostępne w katalogu z plikiem wykonywalnym aplikacji lub w jednej ze ścieżek wymienionych w PATH.</translation>
     </message>
     <message>
         <source>Failed to create %1 context for format %2</source>
@@ -1402,6 +1484,17 @@ Install a driver providing OpenGL 2.0 or higher, or, if this is not possible, ma
         <translation>Przypisanie sygnału błędnie podane</translation>
     </message>
 </context>
+<context>
+    <name>SignalTransition</name>
+    <message>
+        <source>Cannot assign to non-existent property &quot;%1&quot;</source>
+        <translation>Nie można przypisać wartości do nieistniejącej właściwości &quot;%1&quot;</translation>
+    </message>
+    <message>
+        <source>SignalTransition: script expected</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>qmlRegisterType</name>
     <message>
